@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -55,7 +55,7 @@ import com.openexchange.dataretention.RetentionData;
 
 /**
  * {@link CSVRetentionData} - The CSV data retention's implementation of {@link RetentionData}.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class CSVRetentionData implements RetentionData {
@@ -116,12 +116,12 @@ public final class CSVRetentionData implements RetentionData {
     }
 
     public void setRecipientAddresses(final String[] addresses) {
-        this.recipients = new String[addresses.length];
+        recipients = new String[addresses.length];
         System.arraycopy(addresses, 0, recipients, 0, addresses.length);
     }
 
     public void setSenderAddress(final String sender) {
-        this.senderAddress = sender;
+        senderAddress = sender;
     }
 
     public void setStartTime(final Date startTime) {
